@@ -50,9 +50,7 @@ class WasbHook(BaseHook):
     when using Azure compute infrastructure).
 
     :param wasb_conn_id: Reference to the :ref:`wasb connection <howto/connection:wasb>`.
-    :type wasb_conn_id: str
     :param public_read: Whether an anonymous public read access should be used. default is False
-    :type public_read: bool
     """
 
     conn_name_attr = 'wasb_conn_id'
@@ -83,7 +81,7 @@ class WasbHook(BaseHook):
         }
 
     @staticmethod
-    def get_ui_field_behaviour() -> Dict:
+    def get_ui_field_behaviour() -> Dict[str, Any]:
         """Returns custom field behaviour"""
         return {
             "hidden_fields": ['schema', 'port'],
@@ -158,7 +156,6 @@ class WasbHook(BaseHook):
         Instantiates a container client
 
         :param container_name: The name of the container
-        :type container_name: str
         :return: ContainerClient
         """
         return self.connection.get_container_client(container_name)
@@ -168,9 +165,7 @@ class WasbHook(BaseHook):
         Instantiates a blob client
 
         :param container_name: The name of the blob container
-        :type container_name: str
         :param blob_name: The name of the blob. This needs not be existing
-        :type blob_name: str
         """
         container_client = self._get_container_client(container_name)
         return container_client.get_blob_client(blob_name)
@@ -180,11 +175,8 @@ class WasbHook(BaseHook):
         Check if a blob exists on Azure Blob Storage.
 
         :param container_name: Name of the container.
-        :type container_name: str
         :param blob_name: Name of the blob.
-        :type blob_name: str
         :param kwargs: Optional keyword arguments for ``BlobClient.get_blob_properties`` takes.
-        :type kwargs: object
         :return: True if the blob exists, False otherwise.
         :rtype: bool
         """
@@ -199,11 +191,8 @@ class WasbHook(BaseHook):
         Check if a prefix exists on Azure Blob storage.
 
         :param container_name: Name of the container.
-        :type container_name: str
         :param prefix: Prefix of the blob.
-        :type prefix: str
         :param kwargs: Optional keyword arguments that ``ContainerClient.walk_blobs`` takes
-        :type kwargs: object
         :return: True if blobs matching the prefix exist, False otherwise.
         :rtype: bool
         """
@@ -222,16 +211,12 @@ class WasbHook(BaseHook):
         List blobs in a given container
 
         :param container_name: The name of the container
-        :type container_name: str
         :param prefix: Filters the results to return only blobs whose names
             begin with the specified prefix.
-        :type prefix: str
         :param include: Specifies one or more additional datasets to include in the
             response. Options include: ``snapshots``, ``metadata``, ``uncommittedblobs``,
             ``copy`, ``deleted``.
-        :type include: List[str]
         :param delimiter: filters objects based on the delimiter (for e.g '.csv')
-        :type delimiter: str
         """
         container = self._get_container_client(container_name)
         blob_list = []
@@ -245,13 +230,9 @@ class WasbHook(BaseHook):
         Upload a file to Azure Blob Storage.
 
         :param file_path: Path to the file to load.
-        :type file_path: str
         :param container_name: Name of the container.
-        :type container_name: str
         :param blob_name: Name of the blob.
-        :type blob_name: str
         :param kwargs: Optional keyword arguments that ``BlobClient.upload_blob()`` takes.
-        :type kwargs: object
         """
         with open(file_path, 'rb') as data:
             self.upload(container_name=container_name, blob_name=blob_name, data=data, **kwargs)
@@ -261,13 +242,9 @@ class WasbHook(BaseHook):
         Upload a string to Azure Blob Storage.
 
         :param string_data: String to load.
-        :type string_data: str
         :param container_name: Name of the container.
-        :type container_name: str
         :param blob_name: Name of the blob.
-        :type blob_name: str
         :param kwargs: Optional keyword arguments that ``BlobClient.upload()`` takes.
-        :type kwargs: object
         """
         # Reorder the argument order from airflow.providers.amazon.aws.hooks.s3.load_string.
         self.upload(container_name, blob_name, string_data, **kwargs)
@@ -277,13 +254,9 @@ class WasbHook(BaseHook):
         Download a file from Azure Blob Storage.
 
         :param file_path: Path to the file to download.
-        :type file_path: str
         :param container_name: Name of the container.
-        :type container_name: str
         :param blob_name: Name of the blob.
-        :type blob_name: str
         :param kwargs: Optional keyword arguments that `BlobClient.download_blob()` takes.
-        :type kwargs: object
         """
         with open(file_path, "wb") as fileblob:
             stream = self.download(container_name=container_name, blob_name=blob_name, **kwargs)
@@ -294,11 +267,8 @@ class WasbHook(BaseHook):
         Read a file from Azure Blob Storage and return as a string.
 
         :param container_name: Name of the container.
-        :type container_name: str
         :param blob_name: Name of the blob.
-        :type blob_name: str
         :param kwargs: Optional keyword arguments that `BlobClient.download_blob` takes.
-        :type kwargs: object
         """
         return self.download(container_name, blob_name, **kwargs).content_as_text()
 
@@ -315,16 +285,12 @@ class WasbHook(BaseHook):
         Creates a new blob from a data source with automatic chunking.
 
         :param container_name: The name of the container to upload data
-        :type container_name: str
         :param blob_name: The name of the blob to upload. This need not exist in the container
-        :type blob_name: str
         :param data: The blob data to upload
         :param blob_type: The type of the blob. This can be either ``BlockBlob``,
             ``PageBlob`` or ``AppendBlob``. The default value is ``BlockBlob``.
-        :type blob_type: storage.BlobType
         :param length: Number of bytes to read from the stream. This is optional,
             but should be supplied for optimal performance.
-        :type length: int
         """
         container_client = self.create_container(container_name)
         blob_client = container_client.get_blob_client(blob_name)
@@ -337,14 +303,10 @@ class WasbHook(BaseHook):
         Downloads a blob to the StorageStreamDownloader
 
         :param container_name: The name of the container containing the blob
-        :type container_name: str
         :param blob_name: The name of the blob to download
-        :type blob_name: str
         :param offset: Start of byte range to use for downloading a section of the blob.
             Must be set if length is provided.
-        :type offset: int
         :param length: Number of bytes to read from the stream.
-        :type length: int
         """
         blob_client = self._get_blob_client(container_name, blob_name)
         return blob_client.download_blob(offset=offset, length=length, **kwargs)
@@ -354,7 +316,6 @@ class WasbHook(BaseHook):
         Create container object if not already existing
 
         :param container_name: The name of the container to create
-        :type container_name: str
         """
         container_client = self._get_container_client(container_name)
         try:
@@ -374,7 +335,6 @@ class WasbHook(BaseHook):
         Delete a container object
 
         :param container_name: The name of the container
-        :type container_name: str
         """
         try:
             self.log.debug('Attempting to delete container: %s', container_name)
@@ -391,10 +351,8 @@ class WasbHook(BaseHook):
         Marks the specified blobs or snapshots for deletion.
 
         :param container_name: The name of the container containing the blobs
-        :type container_name: str
         :param blobs: The blobs to delete. This can be a single blob, or multiple values
             can be supplied, where each value is either the name of the blob (str) or BlobProperties.
-        :type blobs: Union[str, BlobProperties]
         """
         self._get_container_client(container_name).delete_blobs(*blobs, **kwargs)
         self.log.info("Deleted blobs: %s", blobs)
@@ -412,16 +370,11 @@ class WasbHook(BaseHook):
         Delete a file from Azure Blob Storage.
 
         :param container_name: Name of the container.
-        :type container_name: str
         :param blob_name: Name of the blob.
-        :type blob_name: str
         :param is_prefix: If blob_name is a prefix, delete all matching files
-        :type is_prefix: bool
         :param ignore_if_missing: if True, then return success even if the
             blob does not exist.
-        :type ignore_if_missing: bool
         :param kwargs: Optional keyword arguments that ``ContainerClient.delete_blobs()`` takes.
-        :type kwargs: object
         """
         if is_prefix:
             blobs_to_delete = self.get_blobs_list(
