@@ -30,16 +30,11 @@ class LocalFilesystemToWasbOperator(BaseOperator):
     Uploads a file to Azure Blob Storage.
 
     :param file_path: Path to the file to load. (templated)
-    :type file_path: str
     :param container_name: Name of the container. (templated)
-    :type container_name: str
     :param blob_name: Name of the blob. (templated)
-    :type blob_name: str
     :param wasb_conn_id: Reference to the wasb connection.
-    :type wasb_conn_id: str
     :param load_options: Optional keyword arguments that
         `WasbHook.load_file()` takes.
-    :type load_options: Optional[dict]
     """
 
     template_fields: Sequence[str] = ('file_path', 'container_name', 'blob_name')
